@@ -5,6 +5,7 @@
     :license: MIT, see LICENSE for more details.
 """
 
+import copy
 import SoftLayer
 from SoftLayer import exceptions
 from SoftLayer import fixtures
@@ -25,33 +26,87 @@ class BlockTests(testing.TestCase):
             identifier=449,
         )
 
+    def test_cancel_block_volume_immediately_hourly_billing(self):
+        mock = self.set_mock('SoftLayer_Network_Storage', 'getObject')
+        mock.return_value = {
+            'billingItem': {'hourlyFlag': True, 'id': 449},
+        }
+
+        self.block.cancel_block_volume(123, immediate=False)
+
+        self.assert_called_with(
+            'SoftLayer_Billing_Item',
+            'cancelItem',
+            args=(True, True, 'No longer needed'),
+            identifier=449,
+        )
+
+    def test_cancel_block_volume_exception_billing_item_not_found(self):
+        mock = self.set_mock('SoftLayer_Network_Storage', 'getObject')
+        mock.return_value = {
+            'capacityGb': 20,
+            'createDate': '2017-06-20T14:24:21-06:00',
+            'nasType': 'ISCSI',
+            'storageTypeId': '7',
+            'serviceResourceName': 'PerfStor Aggr aggr_staasdal0601_pc01'
+        }
+        exception = self.assertRaises(
+            exceptions.SoftLayerError,
+            self.block.cancel_block_volume,
+            12345,
+            immediate=True
+        )
+        self.assertEqual(
+            'Block Storage was already cancelled',
+            str(exception)
+        )
+
+    def test_cancel_block_volume_billing_item_found(self):
+        mock = self.set_mock('SoftLayer_Network_Storage', 'getObject')
+        mock.return_value = {
+            'capacityGb': 20,
+            'createDate': '2017-06-20T14:24:21-06:00',
+            'nasType': 'ISCSI',
+            'storageTypeId': '7',
+            'serviceResourceName': 'PerfStor Aggr aggr_staasdal0601_pc01',
+            'billingItem': {'hourlyFlag': True, 'id': 449},
+        }
+        self.block.cancel_block_volume(123, immediate=False)
+
+        self.assert_called_with(
+            'SoftLayer_Billing_Item',
+            'cancelItem',
+            args=(True, True, 'No longer needed'),
+            identifier=449,
+        )
+
     def test_get_block_volume_details(self):
         result = self.block.get_block_volume_details(100)
 
         self.assertEqual(fixtures.SoftLayer_Network_Storage.getObject, result)
 
-        expected_mask = 'id,'\
-                        'username,'\
-                        'password,'\
-                        'capacityGb,'\
-                        'snapshotCapacityGb,'\
-                        'parentVolume.snapshotSizeBytes,'\
-                        'storageType.keyName,'\
-                        'serviceResource.datacenter[name],'\
-                        'serviceResourceBackendIpAddress,'\
-                        'storageTierLevel,'\
-                        'iops,'\
-                        'lunId,'\
-                        'originalVolumeName,'\
-                        'originalSnapshotName,'\
-                        'originalVolumeSize,'\
-                        'activeTransactionCount,'\
-                        'activeTransactions.transactionStatus[friendlyName],'\
-                        'replicationPartnerCount,'\
-                        'replicationStatus,'\
-                        'replicationPartners[id,username,'\
-                        'serviceResourceBackendIpAddress,'\
-                        'serviceResource[datacenter[name]],'\
+        expected_mask = 'id,' \
+                        'username,' \
+                        'password,' \
+                        'capacityGb,' \
+                        'snapshotCapacityGb,' \
+                        'parentVolume.snapshotSizeBytes,' \
+                        'storageType.keyName,' \
+                        'serviceResource.datacenter[name],' \
+                        'serviceResourceBackendIpAddress,' \
+                        'storageTierLevel,' \
+                        'provisionedIops,' \
+                        'lunId,' \
+                        'originalVolumeName,' \
+                        'originalSnapshotName,' \
+                        'originalVolumeSize,' \
+                        'activeTransactionCount,' \
+                        'activeTransactions.transactionStatus[friendlyName],' \
+                        'replicationPartnerCount,' \
+                        'replicationStatus,' \
+                        'replicationPartners[id,username,' \
+                        'serviceResourceBackendIpAddress,' \
+                        'serviceResource[datacenter[name]],' \
                         'replicationSchedule[type[keyname]]]'
 
         self.assert_called_with(
@@ -59,7 +114,7 @@ class BlockTests(testing.TestCase):
             'getObject',
             identifier=100,
             mask='mask[%s]' % expected_mask
-            )
+        )
 
     def test_list_block_volumes(self):
         result = self.block.list_block_volumes()
@@ -80,14 +135,14 @@ class BlockTests(testing.TestCase):
             }
         }
 
-        expected_mask = 'id,'\
-                        'username,'\
-                        'lunId,'\
-                        'capacityGb,'\
-                        'bytesUsed,'\
-                        'serviceResource.datacenter[name],'\
-                        'serviceResourceBackendIpAddress,'\
-                        'activeTransactionCount,'\
+        expected_mask = 'id,' \
+                        'username,' \
+                        'lunId,' \
+                        'capacityGb,' \
+                        'bytesUsed,' \
+                        'serviceResource.datacenter[name],' \
+                        'serviceResourceBackendIpAddress,' \
+                        'activeTransactionCount,' \
                         'replicationPartnerCount'
 
         self.assert_called_with(
@@ -122,14 +177,14 @@ class BlockTests(testing.TestCase):
             }
         }
 
-        expected_mask = 'id,'\
-                        'username,'\
-                        'lunId,'\
-                        'capacityGb,'\
-                        'bytesUsed,'\
-                        'serviceResource.datacenter[name],'\
-                        'serviceResourceBackendIpAddress,'\
-                        'activeTransactionCount,'\
+        expected_mask = 'id,' \
+                        'username,' \
+                        'lunId,' \
+                        'capacityGb,' \
+                        'bytesUsed,' \
+                        'serviceResource.datacenter[name],' \
+                        'serviceResourceBackendIpAddress,' \
+                        'activeTransactionCount,' \
                         'replicationPartnerCount'
 
         self.assert_called_with(
@@ -181,6 +236,48 @@ class BlockTests(testing.TestCase):
             identifier=123,
         )
 
+    def test_cancel_snapshot_hourly_billing_immediate_true(self):
+        mock = self.set_mock('SoftLayer_Network_Storage', 'getObject')
+        mock.return_value = {
+            'billingItem': {
+                'activeChildren': [
+                    {'categoryCode': 'storage_snapshot_space', 'id': 417}
+                ],
+                'hourlyFlag': True,
+                'id': 449
+            },
+        }
+
+        self.block.cancel_snapshot_space(1234, immediate=True)
+
+        self.assert_called_with(
+            'SoftLayer_Billing_Item',
+            'cancelItem',
+            args=(True, True, 'No longer needed'),
+            identifier=417,
+        )
+
+    def test_cancel_snapshot_hourly_billing_immediate_false(self):
+        mock = self.set_mock('SoftLayer_Network_Storage', 'getObject')
+        mock.return_value = {
+            'billingItem': {
+                'activeChildren': [
+                    {'categoryCode': 'storage_snapshot_space', 'id': 417}
+                ],
+                'hourlyFlag': True,
+                'id': 449
+            },
+        }
+
+        self.block.cancel_snapshot_space(1234, immediate=False)
+
+        self.assert_called_with(
+            'SoftLayer_Billing_Item',
+            'cancelItem',
+            args=(True, True, 'No longer needed'),
+            identifier=417,
+        )
+
     def test_cancel_snapshot_exception_no_billing_item_active_children(self):
         mock = self.set_mock('SoftLayer_Network_Storage', 'getObject')
         mock.return_value = {
@@ -231,26 +328,25 @@ class BlockTests(testing.TestCase):
         )
 
     def test_replicant_failover(self):
-        result = self.block.failover_to_replicant(1234, 5678, immediate=True)
+        result = self.block.failover_to_replicant(1234, 5678)
 
         self.assertEqual(
             fixtures.SoftLayer_Network_Storage.failoverToReplicant, result)
         self.assert_called_with(
             'SoftLayer_Network_Storage',
             'failoverToReplicant',
-            args=(5678, True),
+            args=(5678,),
             identifier=1234,
         )
 
     def test_replicant_failback(self):
-        result = self.block.failback_from_replicant(1234, 5678)
+        result = self.block.failback_from_replicant(1234)
 
         self.assertEqual(
             fixtures.SoftLayer_Network_Storage.failbackFromReplicant, result)
         self.assert_called_with(
             'SoftLayer_Network_Storage',
             'failbackFromReplicant',
-            args=(5678,),
             identifier=1234,
         )
 
@@ -279,8 +375,7 @@ class BlockTests(testing.TestCase):
         mock = self.set_mock('SoftLayer_Product_Package', 'getAllObjects')
         mock.return_value = [fixtures.SoftLayer_Product_Package.SAAS_PACKAGE]
 
-        mock_volume = fixtures.SoftLayer_Network_Storage.STAAS_TEST_VOLUME
-        prev_storage_type_keyname = mock_volume['storageType']['keyName']
+        mock_volume = copy.deepcopy(fixtures.SoftLayer_Network_Storage.STAAS_TEST_VOLUME)
         mock_volume['storageType']['keyName'] = 'PERFORMANCE_BLOCK_STORAGE'
         mock = self.set_mock('SoftLayer_Network_Storage', 'getObject')
         mock.return_value = mock_volume
@@ -301,7 +396,7 @@ class BlockTests(testing.TestCase):
             'placeOrder',
             args=({
                 'complexType': 'SoftLayer_Container_Product_Order_'
-                               'Network_Storage_AsAService',
+                'Network_Storage_AsAService',
                 'packageId': 759,
                 'prices': [
                     {'id': 189433},
@@ -313,12 +408,11 @@ class BlockTests(testing.TestCase):
                 'quantity': 1,
                 'location': 449494,
                 'iops': 2000,
+                'useHourlyPricing': False,
                 'osFormatType': {'keyName': 'LINUX'}
             },)
         )
 
-        mock_volume['storageType']['keyName'] = prev_storage_type_keyname
-
     def test_order_block_volume_endurance(self):
         mock = self.set_mock('SoftLayer_Location_Datacenter', 'getDatacenters')
         mock.return_value = [{'id': 449494, 'name': 'dal09'}]
@@ -346,7 +440,7 @@ class BlockTests(testing.TestCase):
             'placeOrder',
             args=({
                 'complexType': 'SoftLayer_Container_Product_Order_'
-                               'Network_Storage_AsAService',
+                'Network_Storage_AsAService',
                 'packageId': 759,
                 'prices': [
                     {'id': 189433},
@@ -357,6 +451,7 @@ class BlockTests(testing.TestCase):
                 'volumeSize': 1000,
                 'quantity': 1,
                 'location': 449494,
+                'useHourlyPricing': False,
                 'osFormatType': {'keyName': 'LINUX'}
             },)
         )
@@ -435,12 +530,27 @@ class BlockTests(testing.TestCase):
             'disableSnapshots',
             identifier=12345678)
 
+    def test_list_volume_schedules(self):
+        result = self.block.list_volume_schedules(12345678)
+
+        self.assertEqual(
+            fixtures.SoftLayer_Network_Storage.listVolumeSchedules,
+            result)
+
+        expected_mask = 'schedules[type,properties[type]]'
+
+        self.assert_called_with(
+            'SoftLayer_Network_Storage',
+            'getObject',
+            identifier=12345678,
+            mask='mask[%s]' % expected_mask
+        )
+
     def test_order_block_snapshot_space_upgrade(self):
         mock = self.set_mock('SoftLayer_Product_Package', 'getAllObjects')
         mock.return_value = [fixtures.SoftLayer_Product_Package.SAAS_PACKAGE]
 
-        mock_volume = fixtures.SoftLayer_Network_Storage.STAAS_TEST_VOLUME
-        prev_storage_type_keyname = mock_volume['storageType']['keyName']
+        mock_volume = copy.deepcopy(fixtures.SoftLayer_Network_Storage.STAAS_TEST_VOLUME)
         mock_volume['storageType']['keyName'] = 'ENDURANCE_BLOCK_STORAGE'
         mock = self.set_mock('SoftLayer_Network_Storage', 'getObject')
         mock.return_value = mock_volume
@@ -454,19 +564,18 @@ class BlockTests(testing.TestCase):
             'placeOrder',
             args=({
                 'complexType': 'SoftLayer_Container_Product_Order_Network_'
-                               'Storage_Enterprise_SnapshotSpace_Upgrade',
+                'Storage_Enterprise_SnapshotSpace_Upgrade',
                 'packageId': 759,
                 'prices': [
                     {'id': 193853}
                 ],
                 'quantity': 1,
                 'location': 449500,
-                'volumeId': 102
+                'volumeId': 102,
+                'useHourlyPricing': False
             },)
         )
 
-        mock_volume['storageType']['keyName'] = prev_storage_type_keyname
-
     def test_order_block_snapshot_space(self):
         mock = self.set_mock('SoftLayer_Product_Package', 'getAllObjects')
         mock.return_value = [fixtures.SoftLayer_Product_Package.SAAS_PACKAGE]
@@ -484,20 +593,20 @@ class BlockTests(testing.TestCase):
             'placeOrder',
             args=({
                 'complexType': 'SoftLayer_Container_Product_Order_Network_'
-                               'Storage_Enterprise_SnapshotSpace',
+                'Storage_Enterprise_SnapshotSpace',
                 'packageId': 759,
                 'prices': [
                     {'id': 193613}
                 ],
                 'quantity': 1,
                 'location': 449500,
-                'volumeId': 102
+                'volumeId': 102,
+                'useHourlyPricing': False
             },)
         )
 
     def test_order_block_replicant_os_type_not_found(self):
-        mock_volume = fixtures.SoftLayer_Network_Storage.STAAS_TEST_VOLUME
-        prev_os_type = mock_volume['osType']
+        mock_volume = copy.deepcopy(fixtures.SoftLayer_Network_Storage.STAAS_TEST_VOLUME)
         del mock_volume['osType']
         mock = self.set_mock('SoftLayer_Network_Storage', 'getObject')
         mock.return_value = mock_volume
@@ -514,8 +623,6 @@ class BlockTests(testing.TestCase):
             str(exception)
         )
 
-        mock_volume['osType'] = prev_os_type
-
     def test_order_block_replicant_performance_os_type_given(self):
         mock = self.set_mock('SoftLayer_Location_Datacenter', 'getDatacenters')
         mock.return_value = [{'id': 449494, 'name': 'dal09'}]
@@ -523,8 +630,7 @@ class BlockTests(testing.TestCase):
         mock = self.set_mock('SoftLayer_Product_Package', 'getAllObjects')
         mock.return_value = [fixtures.SoftLayer_Product_Package.SAAS_PACKAGE]
 
-        mock_volume = fixtures.SoftLayer_Network_Storage.STAAS_TEST_VOLUME
-        prev_storage_type_keyname = mock_volume['storageType']['keyName']
+        mock_volume = copy.deepcopy(fixtures.SoftLayer_Network_Storage.STAAS_TEST_VOLUME)
         mock_volume['storageType']['keyName'] = 'PERFORMANCE_BLOCK_STORAGE'
         mock = self.set_mock('SoftLayer_Network_Storage', 'getObject')
         mock.return_value = mock_volume
@@ -543,7 +649,7 @@ class BlockTests(testing.TestCase):
             'placeOrder',
             args=({
                 'complexType': 'SoftLayer_Container_Product_Order_'
-                               'Network_Storage_AsAService',
+                'Network_Storage_AsAService',
                 'packageId': 759,
                 'prices': [
                     {'id': 189433},
@@ -559,12 +665,11 @@ class BlockTests(testing.TestCase):
                 'iops': 1000,
                 'originVolumeId': 102,
                 'originVolumeScheduleId': 978,
+                'useHourlyPricing': False,
                 'osFormatType': {'keyName': 'XEN'}
             },)
         )
 
-        mock_volume['storageType']['keyName'] = prev_storage_type_keyname
-
     def test_order_block_replicant_endurance(self):
         mock = self.set_mock('SoftLayer_Location_Datacenter', 'getDatacenters')
         mock.return_value = [{'id': 449494, 'name': 'dal09'}]
@@ -585,7 +690,7 @@ class BlockTests(testing.TestCase):
             'placeOrder',
             args=({
                 'complexType': 'SoftLayer_Container_Product_Order_'
-                               'Network_Storage_AsAService',
+                'Network_Storage_AsAService',
                 'packageId': 759,
                 'prices': [
                     {'id': 189433},
@@ -600,6 +705,7 @@ class BlockTests(testing.TestCase):
                 'location': 449494,
                 'originVolumeId': 102,
                 'originVolumeScheduleId': 978,
+                'useHourlyPricing': False,
                 'osFormatType': {'keyName': 'LINUX'}
             },)
         )
@@ -608,8 +714,7 @@ class BlockTests(testing.TestCase):
         mock = self.set_mock('SoftLayer_Product_Package', 'getAllObjects')
         mock.return_value = [fixtures.SoftLayer_Product_Package.SAAS_PACKAGE]
 
-        mock_volume = fixtures.SoftLayer_Network_Storage.STAAS_TEST_VOLUME
-        prev_os_type = mock_volume['osType']
+        mock_volume = copy.deepcopy(fixtures.SoftLayer_Network_Storage.STAAS_TEST_VOLUME)
         del mock_volume['osType']
         mock = self.set_mock('SoftLayer_Network_Storage', 'getObject')
         mock.return_value = mock_volume
@@ -623,14 +728,11 @@ class BlockTests(testing.TestCase):
         self.assertEqual(str(exception),
                          "Cannot find origin volume's os-type")
 
-        mock_volume['osType'] = prev_os_type
-
     def test_order_block_duplicate_performance_no_duplicate_snapshot(self):
         mock = self.set_mock('SoftLayer_Product_Package', 'getAllObjects')
         mock.return_value = [fixtures.SoftLayer_Product_Package.SAAS_PACKAGE]
 
-        mock_volume = fixtures.SoftLayer_Network_Storage.STAAS_TEST_VOLUME
-        prev_storage_type_keyname = mock_volume['storageType']['keyName']
+        mock_volume = copy.deepcopy(fixtures.SoftLayer_Network_Storage.STAAS_TEST_VOLUME)
         mock_volume['storageType']['keyName'] = 'PERFORMANCE_BLOCK_STORAGE'
         mock = self.set_mock('SoftLayer_Network_Storage', 'getObject')
         mock.return_value = mock_volume
@@ -646,7 +748,7 @@ class BlockTests(testing.TestCase):
             'placeOrder',
             args=({
                 'complexType': 'SoftLayer_Container_Product_Order_'
-                               'Network_Storage_AsAService',
+                'Network_Storage_AsAService',
                 'packageId': 759,
                 'prices': [
                     {'id': 189433},
@@ -659,17 +761,15 @@ class BlockTests(testing.TestCase):
                 'location': 449500,
                 'duplicateOriginVolumeId': 102,
                 'osFormatType': {'keyName': 'LINUX'},
-                'iops': 1000
+                'iops': 1000,
+                'useHourlyPricing': False
             },))
 
-        mock_volume['storageType']['keyName'] = prev_storage_type_keyname
-
     def test_order_block_duplicate_performance(self):
         mock = self.set_mock('SoftLayer_Product_Package', 'getAllObjects')
         mock.return_value = [fixtures.SoftLayer_Product_Package.SAAS_PACKAGE]
 
-        mock_volume = fixtures.SoftLayer_Network_Storage.STAAS_TEST_VOLUME
-        prev_storage_type_keyname = mock_volume['storageType']['keyName']
+        mock_volume = copy.deepcopy(fixtures.SoftLayer_Network_Storage.STAAS_TEST_VOLUME)
         mock_volume['storageType']['keyName'] = 'PERFORMANCE_BLOCK_STORAGE'
         mock = self.set_mock('SoftLayer_Network_Storage', 'getObject')
         mock.return_value = mock_volume
@@ -681,7 +781,7 @@ class BlockTests(testing.TestCase):
             duplicate_iops=2000,
             duplicate_tier_level=None,
             duplicate_snapshot_size=10
-            )
+        )
 
         self.assertEqual(fixtures.SoftLayer_Product_Order.placeOrder, result)
 
@@ -690,7 +790,7 @@ class BlockTests(testing.TestCase):
             'placeOrder',
             args=({
                 'complexType': 'SoftLayer_Container_Product_Order_'
-                               'Network_Storage_AsAService',
+                'Network_Storage_AsAService',
                 'packageId': 759,
                 'prices': [
                     {'id': 189433},
@@ -705,11 +805,10 @@ class BlockTests(testing.TestCase):
                 'duplicateOriginVolumeId': 102,
                 'osFormatType': {'keyName': 'LINUX'},
                 'duplicateOriginSnapshotId': 470,
-                'iops': 2000
+                'iops': 2000,
+                'useHourlyPricing': False
             },))
 
-        mock_volume['storageType']['keyName'] = prev_storage_type_keyname
-
     def test_order_block_duplicate_endurance_no_duplicate_snapshot(self):
         mock = self.set_mock('SoftLayer_Product_Package', 'getAllObjects')
         mock.return_value = [fixtures.SoftLayer_Product_Package.SAAS_PACKAGE]
@@ -729,7 +828,7 @@ class BlockTests(testing.TestCase):
             'placeOrder',
             args=({
                 'complexType': 'SoftLayer_Container_Product_Order_'
-                               'Network_Storage_AsAService',
+                'Network_Storage_AsAService',
                 'packageId': 759,
                 'prices': [
                     {'id': 189433},
@@ -741,7 +840,8 @@ class BlockTests(testing.TestCase):
                 'quantity': 1,
                 'location': 449500,
                 'duplicateOriginVolumeId': 102,
-                'osFormatType': {'keyName': 'LINUX'}
+                'osFormatType': {'keyName': 'LINUX'},
+                'useHourlyPricing': False
             },))
 
     def test_order_block_duplicate_endurance(self):
@@ -759,7 +859,7 @@ class BlockTests(testing.TestCase):
             duplicate_iops=None,
             duplicate_tier_level=4,
             duplicate_snapshot_size=10
-            )
+        )
 
         self.assertEqual(fixtures.SoftLayer_Product_Order.placeOrder, result)
 
@@ -768,7 +868,7 @@ class BlockTests(testing.TestCase):
             'placeOrder',
             args=({
                 'complexType': 'SoftLayer_Container_Product_Order_'
-                               'Network_Storage_AsAService',
+                'Network_Storage_AsAService',
                 'packageId': 759,
                 'prices': [
                     {'id': 189433},
@@ -782,9 +882,54 @@ class BlockTests(testing.TestCase):
                 'location': 449500,
                 'duplicateOriginVolumeId': 102,
                 'osFormatType': {'keyName': 'LINUX'},
-                'duplicateOriginSnapshotId': 470
+                'duplicateOriginSnapshotId': 470,
+                'useHourlyPricing': False
             },))
 
+    def test_order_block_modified_performance(self):
+        mock = self.set_mock('SoftLayer_Product_Package', 'getAllObjects')
+        mock.return_value = [fixtures.SoftLayer_Product_Package.SAAS_PACKAGE]
+
+        mock_volume = copy.deepcopy(fixtures.SoftLayer_Network_Storage.STAAS_TEST_VOLUME)
+        mock_volume['storageType']['keyName'] = 'PERFORMANCE_BLOCK_STORAGE'
+        mock = self.set_mock('SoftLayer_Network_Storage', 'getObject')
+        mock.return_value = mock_volume
+
+        result = self.block.order_modified_volume(102, new_size=1000, new_iops=2000, new_tier_level=None)
+
+        self.assertEqual(fixtures.SoftLayer_Product_Order.placeOrder, result)
+        self.assert_called_with(
+            'SoftLayer_Product_Order',
+            'placeOrder',
+            args=({'complexType': 'SoftLayer_Container_Product_Order_Network_Storage_AsAService_Upgrade',
+                   'packageId': 759,
+                   'prices': [{'id': 189433}, {'id': 190113}, {'id': 190173}],
+                   'volume': {'id': 102},
+                   'volumeSize': 1000,
+                   'iops': 2000},)
+        )
+
+    def test_order_block_modified_endurance(self):
+        mock = self.set_mock('SoftLayer_Product_Package', 'getAllObjects')
+        mock.return_value = [fixtures.SoftLayer_Product_Package.SAAS_PACKAGE]
+
+        mock_volume = fixtures.SoftLayer_Network_Storage.STAAS_TEST_VOLUME
+        mock = self.set_mock('SoftLayer_Network_Storage', 'getObject')
+        mock.return_value = mock_volume
+
+        result = self.block.order_modified_volume(102, new_size=1000, new_iops=None, new_tier_level=4)
+
+        self.assertEqual(fixtures.SoftLayer_Product_Order.placeOrder, result)
+        self.assert_called_with(
+            'SoftLayer_Product_Order',
+            'placeOrder',
+            args=({'complexType': 'SoftLayer_Container_Product_Order_Network_Storage_AsAService_Upgrade',
+                   'packageId': 759,
+                   'prices': [{'id': 189433}, {'id': 194763}, {'id': 194703}],
+                   'volume': {'id': 102},
+                   'volumeSize': 1000},)
+        )
+
     def test_setCredentialPassword(self):
         mock = self.set_mock('SoftLayer_Network_Storage_Allowed_Host', 'setCredentialPassword')
         mock.return_value = True
